# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: Security.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='Security.proto',
  package='hadoop.common',
  syntax='proto2',
  serialized_pb=_b('\n\x0eSecurity.proto\x12\rhadoop.common\"Q\n\nTokenProto\x12\x12\n\nidentifier\x18\x01 \x02(\x0c\x12\x10\n\x08password\x18\x02 \x02(\x0c\x12\x0c\n\x04kind\x18\x03 \x02(\t\x12\x0f\n\x07service\x18\x04 \x02(\t\"1\n\x1eGetDelegationTokenRequestProto\x12\x0f\n\x07renewer\x18\x01 \x02(\t\"K\n\x1fGetDelegationTokenResponseProto\x12(\n\x05token\x18\x01 \x01(\x0b\x32\x19.hadoop.common.TokenProto\"L\n RenewDelegationTokenRequestProto\x12(\n\x05token\x18\x01 \x02(\x0b\x32\x19.hadoop.common.TokenProto\":\n!RenewDelegationTokenResponseProto\x12\x15\n\rnewExpiryTime\x18\x01 \x02(\x04\"M\n!CancelDelegationTokenRequestProto\x12(\n\x05token\x18\x01 \x02(\x0b\x32\x19.hadoop.common.TokenProto\"$\n\"CancelDelegationTokenResponseProtoB8\n org.apache.hadoop.security.protoB\x0eSecurityProtos\x88\x01\x01\xa0\x01\x01')
)
_sym_db.RegisterFileDescriptor(DESCRIPTOR)




_TOKENPROTO = _descriptor.Descriptor(
  name='TokenProto',
  full_name='hadoop.common.TokenProto',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='identifier', full_name='hadoop.common.TokenProto.identifier', index=0,
      number=1, type=12, cpp_type=9, label=2,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='password', full_name='hadoop.common.TokenProto.password', index=1,
      number=2, type=12, cpp_type=9, label=2,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='kind', full_name='hadoop.common.TokenProto.kind', index=2,
      number=3, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='service', full_name='hadoop.common.TokenProto.service', index=3,
      number=4, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=33,
  serialized_end=114,
)


_GETDELEGATIONTOKENREQUESTPROTO = _descriptor.Descriptor(
  name='GetDelegationTokenRequestProto',
  full_name='hadoop.common.GetDelegationTokenRequestProto',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='renewer', full_name='hadoop.common.GetDelegationTokenRequestProto.renewer', index=0,
      number=1, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=116,
  serialized_end=165,
)


_GETDELEGATIONTOKENRESPONSEPROTO = _descriptor.Descriptor(
  name='GetDelegationTokenResponseProto',
  full_name='hadoop.common.GetDelegationTokenResponseProto',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='token', full_name='hadoop.common.GetDelegationTokenResponseProto.token', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=167,
  serialized_end=242,
)


_RENEWDELEGATIONTOKENREQUESTPROTO = _descriptor.Descriptor(
  name='RenewDelegationTokenRequestProto',
  full_name='hadoop.common.RenewDelegationTokenRequestProto',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='token', full_name='hadoop.common.RenewDelegationTokenRequestProto.token', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=244,
  serialized_end=320,
)


_RENEWDELEGATIONTOKENRESPONSEPROTO = _descriptor.Descriptor(
  name='RenewDelegationTokenResponseProto',
  full_name='hadoop.common.RenewDelegationTokenResponseProto',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='newExpiryTime', full_name='hadoop.common.RenewDelegationTokenResponseProto.newExpiryTime', index=0,
      number=1, type=4, cpp_type=4, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=322,
  serialized_end=380,
)


_CANCELDELEGATIONTOKENREQUESTPROTO = _descriptor.Descriptor(
  name='CancelDelegationTokenRequestProto',
  full_name='hadoop.common.CancelDelegationTokenRequestProto',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='token', full_name='hadoop.common.CancelDelegationTokenRequestProto.token', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=382,
  serialized_end=459,
)


_CANCELDELEGATIONTOKENRESPONSEPROTO = _descriptor.Descriptor(
  name='CancelDelegationTokenResponseProto',
  full_name='hadoop.common.CancelDelegationTokenResponseProto',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=461,
  serialized_end=497,
)

_GETDELEGATIONTOKENRESPONSEPROTO.fields_by_name['token'].message_type = _TOKENPROTO
_RENEWDELEGATIONTOKENREQUESTPROTO.fields_by_name['token'].message_type = _TOKENPROTO
_CANCELDELEGATIONTOKENREQUESTPROTO.fields_by_name['token'].message_type = _TOKENPROTO
DESCRIPTOR.message_types_by_name['TokenProto'] = _TOKENPROTO
DESCRIPTOR.message_types_by_name['GetDelegationTokenRequestProto'] = _GETDELEGATIONTOKENREQUESTPROTO
DESCRIPTOR.message_types_by_name['GetDelegationTokenResponseProto'] = _GETDELEGATIONTOKENRESPONSEPROTO
DESCRIPTOR.message_types_by_name['RenewDelegationTokenRequestProto'] = _RENEWDELEGATIONTOKENREQUESTPROTO
DESCRIPTOR.message_types_by_name['RenewDelegationTokenResponseProto'] = _RENEWDELEGATIONTOKENRESPONSEPROTO
DESCRIPTOR.message_types_by_name['CancelDelegationTokenRequestProto'] = _CANCELDELEGATIONTOKENREQUESTPROTO
DESCRIPTOR.message_types_by_name['CancelDelegationTokenResponseProto'] = _CANCELDELEGATIONTOKENRESPONSEPROTO

TokenProto = _reflection.GeneratedProtocolMessageType('TokenProto', (_message.Message,), dict(
  DESCRIPTOR = _TOKENPROTO,
  __module__ = 'Security_pb2'
  # @@protoc_insertion_point(class_scope:hadoop.common.TokenProto)
  ))
_sym_db.RegisterMessage(TokenProto)

GetDelegationTokenRequestProto = _reflection.GeneratedProtocolMessageType('GetDelegationTokenRequestProto', (_message.Message,), dict(
  DESCRIPTOR = _GETDELEGATIONTOKENREQUESTPROTO,
  __module__ = 'Security_pb2'
  # @@protoc_insertion_point(class_scope:hadoop.common.GetDelegationTokenRequestProto)
  ))
_sym_db.RegisterMessage(GetDelegationTokenRequestProto)

GetDelegationTokenResponseProto = _reflection.GeneratedProtocolMessageType('GetDelegationTokenResponseProto', (_message.Message,), dict(
  DESCRIPTOR = _GETDELEGATIONTOKENRESPONSEPROTO,
  __module__ = 'Security_pb2'
  # @@protoc_insertion_point(class_scope:hadoop.common.GetDelegationTokenResponseProto)
  ))
_sym_db.RegisterMessage(GetDelegationTokenResponseProto)

RenewDelegationTokenRequestProto = _reflection.GeneratedProtocolMessageType('RenewDelegationTokenRequestProto', (_message.Message,), dict(
  DESCRIPTOR = _RENEWDELEGATIONTOKENREQUESTPROTO,
  __module__ = 'Security_pb2'
  # @@protoc_insertion_point(class_scope:hadoop.common.RenewDelegationTokenRequestProto)
  ))
_sym_db.RegisterMessage(RenewDelegationTokenRequestProto)

RenewDelegationTokenResponseProto = _reflection.GeneratedProtocolMessageType('RenewDelegationTokenResponseProto', (_message.Message,), dict(
  DESCRIPTOR = _RENEWDELEGATIONTOKENRESPONSEPROTO,
  __module__ = 'Security_pb2'
  # @@protoc_insertion_point(class_scope:hadoop.common.RenewDelegationTokenResponseProto)
  ))
_sym_db.RegisterMessage(RenewDelegationTokenResponseProto)

CancelDelegationTokenRequestProto = _reflection.GeneratedProtocolMessageType('CancelDelegationTokenRequestProto', (_message.Message,), dict(
  DESCRIPTOR = _CANCELDELEGATIONTOKENREQUESTPROTO,
  __module__ = 'Security_pb2'
  # @@protoc_insertion_point(class_scope:hadoop.common.CancelDelegationTokenRequestProto)
  ))
_sym_db.RegisterMessage(CancelDelegationTokenRequestProto)

CancelDelegationTokenResponseProto = _reflection.GeneratedProtocolMessageType('CancelDelegationTokenResponseProto', (_message.Message,), dict(
  DESCRIPTOR = _CANCELDELEGATIONTOKENRESPONSEPROTO,
  __module__ = 'Security_pb2'
  # @@protoc_insertion_point(class_scope:hadoop.common.CancelDelegationTokenResponseProto)
  ))
_sym_db.RegisterMessage(CancelDelegationTokenResponseProto)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), _b('\n org.apache.hadoop.security.protoB\016SecurityProtos\210\001\001\240\001\001'))
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Copyright (c) 2015 Bolke de Bruin
#
# Permission is hereby granted, free of charge, to any person obtaining a copy
# of this software and associated documentation files (the "Software"), to deal
# in the Software without restriction, including without limitation the rights
# to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
# copies of the Software, and to permit persons to whom the Software is
# furnished to do so, subject to the following conditions:
#
# The above copyright notice and this permission notice shall be included in
# all copies or substantial portions of the Software.
#
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
# THE SOFTWARE.
'''
kerberos.py - A very light wrapper around gssapi

This package contains a class to read a kerberos principal

May 2015 (original implementation with krbV)

Bolke de Bruin (bolke@xs4all.nl)

Nov 2019 (implementation with gssapi for Python3)

Luca Toscano (toscano.luca@gmail.com)

'''

# python 3 support
from __future__ import absolute_import, print_function, division

import gssapi

class Kerberos:
    def __init__(self):
        self.credentials = gssapi.Credentials(usage='initiate')

    def user_principal(self):
        return str(self.credentials.inquire().name)

